@@ -3,22 +3,22 @@
 <context>
     <name>GpxDocument</name>
     <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="127"/>
+        <location filename="../../gpxviewer/gpxdocument.py" line="93"/>
         <source>The file </source>
         <translation>Файл </translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="127"/>
+        <location filename="../../gpxviewer/gpxdocument.py" line="93"/>
         <source> doesn&apos;t exist.</source>
         <translation> не существует.</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="134"/>
+        <location filename="../../gpxviewer/gpxdocument.py" line="135"/>
         <source>This file in not a valid GPX Viewer project file.</source>
         <translation>Этот файл не является файлом проекта GPX Viewer.</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="131"/>
+        <location filename="../../gpxviewer/gpxdocument.py" line="97"/>
         <source>One of the files:
 
 </source>
@@ -27,7 +27,7 @@
 </translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="131"/>
+        <location filename="../../gpxviewer/gpxdocument.py" line="97"/>
         <source>has wrong number of valid waypoints. This file is likely to be damaged or changed from outside.</source>
         <translation>содержит неправильное количество маршрутных точек. Вероятно, этот файл повреждён.</translation>
     </message>
@@ -110,27 +110,27 @@
         <translation>О GPX Viewer</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="370"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="385"/>
         <source>Distance Profile</source>
         <translation>Профиль по расстоянию</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="386"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="401"/>
         <source>Time Profile</source>
         <translation>Профиль по времени</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="284"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="285"/>
         <source>Open GPX file</source>
         <translation>Открыть GPX файл</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="301"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="313"/>
         <source>Open project file</source>
         <translation>Открыть файл проекта</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="317"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="329"/>
         <source>Save project file as</source>
         <translation>Сохранить файл проекта как</translation>
     </message>
@@ -160,7 +160,7 @@
         <translation>Зактыть GPX Viewer</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="291"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="303"/>
         <source>There are unsaved changes. Do you want to save the project?</source>
         <translation>Есть несохранённые изменения. Вы хотите сохранить проект?</translation>
     </message>
@@ -170,45 +170,75 @@
         <translation>Загрузить GPX файл</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="291"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="303"/>
         <source>Open GPX Viewer project</source>
         <translation>Открыть проект GPX Viewer</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="284"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="295"/>
         <source>GPX XML (*.gpx);;All files (*)</source>
         <translation>GPX XML (*.gpx);;Все файлы (*.*)</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="357"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="372"/>
         <source>File read error</source>
         <translation>Ошибка чтения файла</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="317"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="329"/>
         <source>GPX Viewer Projects (*.gpxv);;All files (*)</source>
         <translation>Проекты GPX Viewer (*.gpxv);;Все файлы (*.*)</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="339"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="354"/>
         <source>Multiple GPX files</source>
         <translation>Несколько GPX файлов</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="383"/>
-        <source>Plot Error</source>
-        <translation>Ошибка отрисовки</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="367"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="382"/>
         <source>Not enouph points with distance.</source>
         <translation>Недостаточно точек с расстоянием.</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="383"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="398"/>
         <source>Not enouph points with timestamps.</source>
         <translation>Недостаточно точек с отметками времени.</translation>
     </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="295"/>
+        <source>Save GPX file as</source>
+        <translation>Сохранить GPX файл как</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="408"/>
+        <source>Not enouph points.</source>
+        <translation>Недостаточно точек.</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="292"/>
+        <source>The GPX file will be empty.</source>
+        <translation>GPX файл будет пуст.</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="342"/>
+        <source>The project is empty.</source>
+        <translation>Проект пуст.</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="342"/>
+        <source>Save error</source>
+        <translation>Ошибка сохранения</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="398"/>
+        <source>Plot error</source>
+        <translation>Ошибка отрисовки</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="408"/>
+        <source>Statistics error</source>
+        <translation>Ошибка расчёта статистики</translation>
+    </message>
 </context>
 <context>
     <name>GpxModel</name>
@@ -380,6 +410,11 @@
         <source>&amp;Statistics</source>
         <translation>&amp;Статистика</translation>
     </message>
+    <message>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="188"/>
+        <source>Save &amp;GPX file as...</source>
+        <translation>Сохранить &amp;GPX файл как...</translation>
+    </message>
 </context>
 <context>
     <name>PlotCanvas</name>
@@ -522,7 +557,7 @@
     <message>
         <location filename="../../gpxviewer/pointconfigdialog.py" line="57"/>
         <source>X</source>
-        <translation type="unfinished"></translation>
+        <translation>Крест</translation>
     </message>
     <message>
         <location filename="../../gpxviewer/pointconfigdialog.py" line="58"/>
@@ -562,48 +597,48 @@
     <message>
         <location filename="../../gpxviewer/pointconfigdialog.py" line="65"/>
         <source>Dotted</source>
-        <translation>Штриховая </translation>
+        <translation>Штриховая</translation>
     </message>
 </context>
 <context>
     <name>StatWindow</name>
     <message>
-        <location filename="../../gpxviewer/ui_statwindow.py" line="118"/>
+        <location filename="../../gpxviewer/ui_statwindow.py" line="119"/>
         <source>Name</source>
         <translation>Название</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_statwindow.py" line="128"/>
+        <location filename="../../gpxviewer/ui_statwindow.py" line="129"/>
         <source>Distance</source>
         <translation>Расстояние</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_statwindow.py" line="129"/>
+        <location filename="../../gpxviewer/ui_statwindow.py" line="130"/>
         <source>Altitude raise</source>
         <translation>Набор высоты</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_statwindow.py" line="130"/>
+        <location filename="../../gpxviewer/ui_statwindow.py" line="131"/>
         <source>Altitude drop</source>
         <translation>Сброс высоты</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_statwindow.py" line="131"/>
+        <location filename="../../gpxviewer/ui_statwindow.py" line="132"/>
         <source>Time</source>
         <translation>Время</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_statwindow.py" line="127"/>
+        <location filename="../../gpxviewer/ui_statwindow.py" line="128"/>
         <source>Total</source>
         <translation>Всего</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_statwindow.py" line="116"/>
+        <location filename="../../gpxviewer/ui_statwindow.py" line="117"/>
         <source>Statistics</source>
         <translation>Статистика</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_statwindow.py" line="132"/>
+        <location filename="../../gpxviewer/ui_statwindow.py" line="133"/>
         <source>By splitting lines</source>
         <translation>По разделительным линиям</translation>
     </message>
